@@ -51,6 +51,7 @@ class Strategy:
     # Arguments
     availability_vs_cost: str
     risk: int
+    utilize_commitments: bool
     utilize_reserved_instances: bool
     fallback_to_od: bool
     on_demand_count: int
@@ -66,6 +67,7 @@ class Strategy:
             self,
             availability_vs_cost=none,
             risk=none,
+            utilize_commitments=none,
             utilize_reserved_instances=none,
             fallback_to_od=none,
             on_demand_count=none,
@@ -75,9 +77,11 @@ class Strategy:
             signals=none,
             scaling_strategy=none,
             persistence=none,
-            revert_to_spot=none):
+            revert_to_spot=none,
+            immediate_o_d_recover_threshold = none):
 
         self.risk = risk
+        self.utilize_commitments = utilize_commitments
         self.utilize_reserved_instances = utilize_reserved_instances
         self.fallback_to_od = fallback_to_od
         self.on_demand_count = on_demand_count
@@ -90,6 +94,7 @@ class Strategy:
         self.scaling_strategy = scaling_strategy
         self.persistence = persistence
         self.revert_to_spot = revert_to_spot
+        self.immediate_o_d_recover_threshold = immediate_o_d_recover_threshold
 
 
 class Signal:
@@ -1120,11 +1125,11 @@ class Compute:
 
 class AvailabilityZone:
     """
-    # Aerguments
-    name:
-    subnet_id:
-    subnet_ids:
-    placement_group_name:
+    # Arguments
+    name: str
+    subnet_id: str
+    subnet_ids: list
+    placement_group_name: str
     """
     def __init__(
             self,
@@ -1203,6 +1208,7 @@ class LaunchSpecification:
     security_group_ids: list[str]
     credit_specification: CreditSpecification
     image_id: str
+    images: list[Image]
     monitoring: bool
     health_check_type: str
     load_balancers_config:  LoadBalancersConfig
@@ -1218,11 +1224,15 @@ class LaunchSpecification:
     network_interfaces: list[NetworkInterface]
     tags: list[Tag]
     resource_tag_specification: ResourceTagSpecification
+    auto_healing: bool
+    cpu_options: CpuOptions
+    metadata_options: MetadataOptions
     """
     def __init__(
             self,
             security_group_ids=none,
             image_id=none,
+            images=none,
             monitoring=none,
             credit_specification=none,
             health_check_type=none,
@@ -1238,7 +1248,10 @@ class LaunchSpecification:
             block_device_mappings=none,
             network_interfaces=none,
             tags=none,
-            resource_tag_specification=none):
+            resource_tag_specification=none,
+            auto_healing=none,
+            cpu_options=none,
+            metadata_options=none):
 
         self.load_balancers_config = load_balancers_config
         self.health_check_type = health_check_type
@@ -1249,6 +1262,7 @@ class LaunchSpecification:
         self.credit_specification = credit_specification
         self.ebs_optimized = ebs_optimized
         self.image_id = image_id
+        self.images = images
         self.tenancy = tenancy
         self.iam_role = iam_role
         self.key_pair = key_pair
@@ -1258,6 +1272,9 @@ class LaunchSpecification:
         self.network_interfaces = network_interfaces
         self.tags = tags
         self.resource_tag_specification = resource_tag_specification
+        self.auto_healing = auto_healing
+        self.cpu_options = cpu_options
+        self.metadata_options = metadata_options
 
 
 class CreditSpecification:
@@ -1271,6 +1288,19 @@ class CreditSpecification:
 
         self.cpu_credits = cpu_credits
 
+
+class Image:
+    """
+    # Arguments
+    id: str
+    """
+    def __init__(
+        self,
+        id=none):
+
+        self.id = id
+
+
 class LoadBalancersConfig:
     """
     # Arguments
@@ -1379,6 +1409,7 @@ class EBS:
         self.dynamic_volume_size = dynamic_volume_size
         self.throughput = throughput
 
+
 class DynamicVolumeSize:
     """
     # Arguments
@@ -1463,6 +1494,32 @@ class PrivateIpAddress:
         self.primary = primary
 
 
+class CpuOptions:
+    """
+    # Arguments
+    threads_per_core: int
+    """
+    def __init__(self, threads_per_core=none):
+
+        self.threads_per_core = threads_per_core
+
+
+class MetadataOptions:
+    """
+    # Arguments
+    http_put_response_hop_limit: int
+    http_tokens: str
+    instance_metadata_tags: str
+    """
+    def __init__(self, 
+                 http_put_response_hop_limit=none,
+                 http_tokens=none,
+                 instance_metadata_tags=none):
+
+        self.http_put_response_hop_limit = http_put_response_hop_limit
+        self.http_tokens = http_tokens
+        self.instance_metadata_tags = instance_metadata_tags
+
 # endregion
 
 class Roll:
